@@ -5,11 +5,9 @@ import time
 
 from .constants import (
     LOGGER,
-    ControlSource,
-    ControlVolume,
-    ServiceBrowse,
-    ServiceRegistry,
-    ServiceTransport,
+    SERVICE_BROWSE,
+    SERVICE_REGISTRY,
+    SERVICE_TRANSPORT,
 )
 from .discovery import RoonDiscovery
 from .roonapisocket import RoonApiWebSocket
@@ -21,15 +19,14 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
     _roonsocket = None
     _roondiscovery = None
     _host = None
+    _core_id = None
+    _core_name = None
+
     _port = None
     _token = None
     _exit = False
     _zones = {}
     _outputs = {}
-    _source_controls_request_id = None
-    _volume_controls_request_id = None
-    _source_controls = {}
-    _volume_controls = {}
     _state_callbacks = []
     ready = False
 
@@ -38,6 +35,21 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
         """Return the authentication key from the registration with Roon."""
         return self._token
 
+    @property
+    def host(self):
+        """Return the roon host."""
+        return self._host
+
+    @property
+    def core_id(self):
+        """Return the roon host."""
+        return self._core_id
+
+    @property
+    def core_name(self):
+        """Return the roon core name."""
+        return self._core_name
+
     @property
     def zones(self):
         """Return All zones as a dict."""
@@ -121,7 +133,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
                  * "next" - Advance to the next track
         """
         data = {"zone_or_output_id": zone_or_output_id, "control": control}
-        return self._request(ServiceTransport + "/control", data)
+        return self._request(SERVICE_TRANSPORT + "/control", data)
 
     def standby(self, output_id, control_key=None):
         """
@@ -135,7 +147,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
                          standby will be put into standby.
         """
         data = {"output_id": output_id, "control_key": control_key}
-        return self._request(ServiceTransport + "/standby", data)
+        return self._request(SERVICE_TRANSPORT + "/standby", data)
 
     def convenience_switch(self, output_id, control_key=None):
         """
@@ -147,7 +159,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
                          If omitted, then all controls on this output will be convenience switched.
         """
         data = {"output_id": output_id, "control_key": control_key}
-        return self._request(ServiceTransport + "/convenience_switch", data)
+        return self._request(SERVICE_TRANSPORT + "/convenience_switch", data)
 
     def mute(self, output_id, mute=True):
         """
@@ -159,7 +171,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
         """
         how = "mute" if mute else "unmute"
         data = {"output_id": output_id, "how": how}
-        return self._request(ServiceTransport + "/mute", data)
+        return self._request(SERVICE_TRANSPORT + "/mute", data)
 
     def change_volume(self, output_id, value, method="absolute"):
         """
@@ -182,7 +194,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
                 if self._outputs[output_id]["volume"]["type"] == "db":
                     value = int((float(value) / 100) * 80) - 80
             data = {"output_id": output_id, "how": method, "value": value}
-            return self._request(ServiceTransport + "/change_volume", data)
+            return self._request(SERVICE_TRANSPORT + "/change_volume", data)
         except Exception as exc:  # pylint: disable=broad-except
             LOGGER.error("set_volume_level failed for entity %s.", str(exc))
             return None
@@ -201,7 +213,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             "how": method,
             "seconds": seconds,
         }
-        return self._request(ServiceTransport + "/seek", data)
+        return self._request(SERVICE_TRANSPORT + "/seek", data)
 
     def shuffle(self, zone_or_output_id, shuffle=True):
         """
@@ -212,7 +224,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             shuffle: bool if shuffle should be enabled. False will disable shuffle
         """
         data = {"zone_or_output_id": zone_or_output_id, "shuffle": shuffle}
-        return self._request(ServiceTransport + "/change_settings", data)
+        return self._request(SERVICE_TRANSPORT + "/change_settings", data)
 
     def repeat(self, zone_or_output_id, repeat=True):
         """
@@ -224,7 +236,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
         """
         loop = "loop" if repeat else "disabled"
         data = {"zone_or_output_id": zone_or_output_id, "loop": loop}
-        return self._request(ServiceTransport + "/change_settings", data)
+        return self._request(SERVICE_TRANSPORT + "/change_settings", data)
 
     def transfer_zone(self, from_zone_or_output_id, to_zone_or_output_id):
         """
@@ -238,7 +250,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             "from_zone_or_output_id": from_zone_or_output_id,
             "to_zone_or_output_id": to_zone_or_output_id,
         }
-        return self._request(ServiceTransport + "/transfer_zone", data)
+        return self._request(SERVICE_TRANSPORT + "/transfer_zone", data)
 
     def group_outputs(self, output_ids):
         """
@@ -248,7 +260,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             output_ids - The outputs to group. The first output's zone's queue is preserved.
         """
         data = {"output_ids": output_ids}
-        return self._request(ServiceTransport + "/group_outputs", data)
+        return self._request(SERVICE_TRANSPORT + "/group_outputs", data)
 
     def ungroup_outputs(self, output_ids):
         """
@@ -258,89 +270,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             output_ids - The outputs to ungroup.
         """
         data = {"output_ids": output_ids}
-        return self._request(ServiceTransport + "/ungroup_outputs", data)
-
-    # pylint: disable=too-many-arguments
-    def register_source_control(
-        self,
-        control_key,
-        display_name,
-        callback,
-        initial_state="selected",
-        supports_standby=True,
-    ):
-        """Register a new source control on the api."""
-        if control_key in self._source_controls:
-            LOGGER.error("source_control %s is already registered!" % control_key)
-            return
-        control_data = {
-            "display_name": display_name,
-            "supports_standby": supports_standby,
-            "status": initial_state,
-            "control_key": control_key,
-        }
-        self._source_controls[control_key] = (callback, control_data)
-        if self._source_controls_request_id:
-            data = {"controls_added": [control_data]}
-            self._roonsocket.send_continue(self._source_controls_request_id, data)
-
-    def update_source_control(self, control_key, new_state):
-        """Update an existing source control on the api."""
-        if control_key not in self._source_controls:
-            LOGGER.warning("source_control %s is not (yet) registered!" % control_key)
-            return
-        if not self._source_controls_request_id:
-            LOGGER.warning("Not yet registered, can not update source control")
-            return
-        self._source_controls[control_key][1]["status"] = new_state
-        data = {"controls_changed": [self._source_controls[control_key][1]]}
-        self._roonsocket.send_continue(self._source_controls_request_id, data)
-
-    def register_volume_control(
-        self,
-        control_key,
-        display_name,
-        callback,
-        initial_volume=0,
-        volume_type="number",
-        volume_step=2,
-        volume_min=0,
-        volume_max=100,
-        is_muted=False,
-    ):
-        """Register a new volume control on the api."""
-        if control_key in self._volume_controls:
-            LOGGER.error("source_control %s is already registered!" % control_key)
-            return
-        control_data = {
-            "display_name": display_name,
-            "volume_type": volume_type,
-            "volume_min": volume_min,
-            "volume_max": volume_max,
-            "volume_value": initial_volume,
-            "volume_step": volume_step,
-            "is_muted": is_muted,
-            "control_key": control_key,
-        }
-        self._volume_controls[control_key] = (callback, control_data)
-        if self._volume_controls_request_id:
-            data = {"controls_added": [control_data]}
-            self._roonsocket.send_continue(self._volume_controls_request_id, data)
-
-    def update_volume_control(self, control_key, volume=None, mute=None):
-        """Update an existing volume control, report its state to Roon."""
-        if control_key not in self._volume_controls:
-            LOGGER.warning("volume_control %s is not (yet) registered!" % control_key)
-            return
-        if not self._volume_controls_request_id:
-            LOGGER.warning("Not yet registered, can not update volume control")
-            return
-        if volume is not None:
-            self._volume_controls[control_key][1]["volume_value"] = volume
-        if mute is not None:
-            self._volume_controls[control_key][1]["is_muted"] = mute
-        data = {"controls_changed": [self._volume_controls[control_key][1]]}
-        self._roonsocket.send_continue(self._volume_controls_request_id, data)
+        return self._request(SERVICE_TRANSPORT + "/ungroup_outputs", data)
 
     def register_state_callback(self, callback, event_filter=None, id_filter=None):
         """
@@ -375,7 +305,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             opt_data = {"zone_or_output_id": zone_or_output_id}
         else:
             opt_data = None
-        self._roonsocket.subscribe(ServiceTransport, "queue", callback, opt_data)
+        self._roonsocket.subscribe(SERVICE_TRANSPORT, "queue", callback, opt_data)
 
     def browse_browse(self, opts):
         """
@@ -383,7 +313,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
         reference: https://github.com/RoonLabs/node-roon-api-browse/blob/master/lib.js
         """
-        return self._request(ServiceBrowse + "/browse", opts)
+        return self._request(SERVICE_BROWSE + "/browse", opts)
 
     def browse_load(self, opts):
         """
@@ -391,7 +321,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
         reference: https://github.com/RoonLabs/node-roon-api-browse/blob/master/lib.js
         """
-        return self._request(ServiceBrowse + "/load", opts)
+        return self._request(SERVICE_BROWSE + "/load", opts)
 
     def browse_pop_all(self, opts):
         """
@@ -399,7 +329,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
         reference: https://github.com/RoonLabs/node-roon-api-browse/blob/master/lib.js
         """
-        return self._request(ServiceBrowse + "/pop_all", opts)
+        return self._request(SERVICE_BROWSE + "/pop_all", opts)
 
     def browse_pop(self, opts):
         """
@@ -407,7 +337,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
         reference: https://github.com/RoonLabs/node-roon-api-browse/blob/master/lib.js
         """
-        return self._request(ServiceBrowse + "/pop", opts)
+        return self._request(SERVICE_BROWSE + "/pop", opts)
 
     def browse_by_path(
         self, search_paths, zone_or_output_id="", offset=0, search_input=None
@@ -585,7 +515,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
         )
 
     # private methods
-
+    # pylint: disable=too-many-arguments
     def __init__(self, appinfo, token=None, host=None, port=9100, blocking_init=True):
         """
         Set up the connection with Roon.
@@ -644,12 +574,6 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
         self._roonsocket.register_connected_callback(self._socket_connected)
         self._roonsocket.register_registered_calback(self._server_registered)
-        self._roonsocket.register_source_controls_callback(
-            self._on_source_control_request
-        )
-        self._roonsocket.register_volume_controls_callback(
-            self._on_volume_control_request
-        )
 
         self._roonsocket.start()
 
@@ -657,33 +581,34 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
         """Successfully connected the websocket."""
         LOGGER.info("Connection with roon websockets (re)created.")
         self.ready = False
-        self._source_controls_request_id = None
-        self._volume_controls_request_id = None
         # authenticate / register
         # warning: at first launch the user has to approve the app in the Roon settings.
         appinfo = self._appinfo.copy()
-        appinfo["required_services"] = [ServiceTransport, ServiceBrowse]
-        appinfo["provided_services"] = [ControlVolume, ControlSource]
+        appinfo["required_services"] = [SERVICE_TRANSPORT, SERVICE_BROWSE]
+        appinfo["provided_services"] = []
         if self._token:
             appinfo["token"] = self._token
         if not self._token:
             LOGGER.info("The application should be approved within Roon's settings.")
         else:
-            LOGGER.info("Registering the app with Roon...")
-        self._roonsocket.send_request(ServiceRegistry + "/register", appinfo)
+            LOGGER.info("Confirming previous registration with Roon...")
+        self._roonsocket.send_request(SERVICE_REGISTRY + "/register", appinfo)
 
     def _server_registered(self, reginfo):
-        LOGGER.info("Registered to Roon server %s" % reginfo["display_name"])
+        LOGGER.info("Registered to Roon server %s", reginfo["display_name"])
         LOGGER.debug(reginfo)
         self._token = reginfo["token"]
+        self._core_id = reginfo["core_id"]
+        self._core_name = reginfo["display_name"]
+
         # fill zones and outputs dicts one time so the data is available right away
         if not self._zones:
             self._zones = self._get_zones()
         if not self._outputs:
             self._outputs = self._get_outputs()
         # subscribe to state change events
-        self._roonsocket.subscribe(ServiceTransport, "zones", self._on_state_change)
-        self._roonsocket.subscribe(ServiceTransport, "outputs", self._on_state_change)
+        self._roonsocket.subscribe(SERVICE_TRANSPORT, "zones", self._on_state_change)
+        self._roonsocket.subscribe(SERVICE_TRANSPORT, "outputs", self._on_state_change)
         # set flag that we're fully initialized (used for blocking init)
         self.ready = True
 
@@ -757,7 +682,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
     def _get_outputs(self):
         outputs = {}
-        data = self._request(ServiceTransport + "/get_outputs")
+        data = self._request(SERVICE_TRANSPORT + "/get_outputs")
         if data and "outputs" in data:
             for output in data["outputs"]:
                 outputs[output["output_id"]] = output
@@ -765,7 +690,7 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
 
     def _get_zones(self):
         zones = {}
-        data = self._request(ServiceTransport + "/get_zones")
+        data = self._request(SERVICE_TRANSPORT + "/get_zones")
         if data and "zones" in data:
             for zone in data["zones"]:
                 zones[zone["zone_id"]] = zone
@@ -797,64 +722,6 @@ class RoonApi:  # pylint: disable=too-many-instance-attributes
             pass
         return result
 
-    def _on_source_control_request(self, event, request_id, data):
-        """Got request from roon server for a source control registered on this endpoint."""
-        LOGGER.debug("_on_source_control_request")
-        if event == "subscribe_controls":
-            LOGGER.debug("found subscription ID for source controls: %s " % request_id)
-            self._roonsocket.send_continue(request_id, {"controls_added": []})
-            # send all source controls already registered (handle connection loss)
-            controls = []
-            for _, control_data in self._source_controls.values():
-                controls.append(control_data)
-            self._roonsocket.send_continue(request_id, {"controls_added": controls})
-            self._source_controls_request_id = request_id
-        elif data and data.get("control_key"):
-            control_key = data["control_key"]
-            try:
-                # launch callback
-                self._roonsocket.send_complete(request_id, "Success")
-                self._source_controls[control_key][0](control_key, event)
-            except Exception:  # pylint: disable=broad-except
-                LOGGER.exception("Error in source_control callback")
-                self._roonsocket.send_complete(request_id, "Error")
-
-    def _on_volume_control_request(self, event, request_id, data):
-        """Got request from roon server for a volume control registered on this endpoint."""
-        LOGGER.debug("_on_volume_control_request")
-        if event == "subscribe_controls":
-            LOGGER.debug("found subscription ID for volume controls: %s " % request_id)
-            # send all volume controls already registered (handle connection loss)
-            controls = []
-            for _, control_data in self._volume_controls.values():
-                controls.append(control_data)
-            self._roonsocket.send_continue(request_id, {"controls_added": controls})
-            self._source_controls_request_id = request_id
-            self._volume_controls_request_id = request_id
-        elif data and data.get("control_key"):
-            control_key = data["control_key"]
-            if event == "set_volume" and data["mode"] == "absolute":
-                value = data["value"]
-            elif event == "set_volume" and data["mode"] == "relative":
-                value = (
-                    self._volume_controls[control_key][0]["volume_value"]
-                    + data["value"]
-                )
-            elif event == "set_volume" and data["mode"] == "relative_step":
-                value = self._volume_controls[control_key][0]["volume_value"] + (
-                    data["value"] * data["volume_step"]
-                )
-            elif event == "set_mute":
-                value = data["mode"] == "on"
-            else:
-                return
-            try:
-                self._roonsocket.send_complete(request_id, "Success")
-                self._volume_controls[control_key][0](control_key, event, value)
-            except Exception:  # pylint: disable=broad-except
-                LOGGER.exception("Error in volume_control callback")
-                self._roonsocket.send_complete(request_id, "Error")
-
     def _socket_watcher(self):
         """Monitor the connection state of the socket and reconnect if needed."""
         while not self._exit:
